# is-even ![https://pypi.org/project/is-int-even/](https://img.shields.io/pypi/dm/is-int-even)
Returns true if the number passed is even, returns false if it is not.

Inspired by [samuelmarina/is-even](https://github.com/samuelmarina/is-even) and is the python version of it :)

## Installing
```sh
pip install -U git+https://github.com/sifte/is-int-even.git
```

## Example
```py
from is_int_even import is_even

is_even(0) # true
is_even(1) # true
is_even(2) # true
# and so on...  current limit is 125,000
```

